@@ -1,47 +1,51 @@
+use crate::common::json::Get;
 use anyhow::Result;
 use structopt::{self, StructOpt};
 
 mod common;
 mod condition;
-mod payee;
 mod payment;
 mod plan;
+mod profile;
 
 #[derive(Debug, Clone, StructOpt)]
 pub struct Arguments {
-    #[structopt(name = "verbosity", short, long, parse(from_occurrences))]
-    verbosity: u8,
-
     // SUBCOMMANDS
     #[structopt(subcommand)]
-    commands: Option<Subcommands>,
+    commands: Subcommands,
 }
 
 #[derive(Debug, StructOpt, Clone)]
 enum Subcommands {
     /// New lock file.
     New(NewArguments),
-    /// Add plan, payee, etc.
+    /// Add plan, profile, etc.
     Add(AddArguments),
-    /// Remove plan, payee, payment, condition, etc.
+    /// Remove plan, profile, payment, condition, etc.
     Remove(RemoveSubcommands),
+    /// Update payee profiles.
+    Update(UpdateArguments),
+    /// Show lock fields.
+    Show(ShowArguments),
 }
 
 pub fn run_command(args: &Arguments) -> Result<()> {
-    if let Some(subcommand) = &args.commands {
-        match subcommand {
-            Subcommands::New(args) => {
-                new(&args)?;
-            }
-            Subcommands::Add(args) => {
-                add(&args)?;
-            }
-            Subcommands::Remove(args) => {
-                remove(&args)?;
-            }
+    match &args.commands {
+        Subcommands::New(args) => {
+            new(&args)?;
+        }
+        Subcommands::Add(args) => {
+            add(&args)?;
+        }
+        Subcommands::Remove(args) => {
+            remove(&args)?;
+        }
+        Subcommands::Update(args) => {
+            update(&args)?;
+        }
+        Subcommands::Show(args) => {
+            show(&args)?;
         }
-    } else {
-        show(args.verbosity)?;
     }
     Ok(())
 }
@@ -62,7 +66,7 @@ pub struct NewArguments {
 }
 
 fn new(args: &NewArguments) -> Result<()> {
-    let lock_handle = common::LockFileHandle::new(&args.lock_file_args.path, args.force)?;
+    let lock_handle = crate::handles::LockHandle::new(&args.lock_file_args.path, args.force)?;
     println!("Created new lock file: {}", lock_handle.path().display());
     Ok(())
 }
@@ -70,19 +74,15 @@ fn new(args: &NewArguments) -> Result<()> {
 #[derive(Debug, StructOpt, Clone)]
 pub enum AddArguments {
     /// Add plan.
-    #[structopt(name = "plan")]
     Plan(plan::AddArguments),
 
-    /// Add payee to payment plan(s).
-    #[structopt(name = "payee")]
-    Payee(payee::AddArguments),
+    /// Add payee profile to payment plan(s).
+    Profile(profile::AddArguments),
 
     /// Add payment parameters.
-    #[structopt(name = "payment")]
     Payment(payment::AddArguments),
 
     /// Add condition(s) to plan(s).
-    #[structopt(name = "condition")]
     Condition(condition::AddArguments),
 }
 
@@ -91,8 +91,8 @@ fn add(args: &AddArguments) -> Result<()> {
         AddArguments::Plan(args) => {
             plan::add(&args)?;
         }
-        AddArguments::Payee(args) => {
-            payee::add(&args)?;
+        AddArguments::Profile(args) => {
+            profile::add(&args)?;
         }
         AddArguments::Payment(args) => {
             payment::add(&args)?;
@@ -108,19 +108,15 @@ fn add(args: &AddArguments) -> Result<()> {
 #[derive(Debug, StructOpt, Clone)]
 pub enum RemoveSubcommands {
     /// Remove plan.
-    #[structopt(name = "plan")]
     Plan(plan::RemoveArguments),
 
-    /// Remove payee from payment plan(s).
-    #[structopt(name = "payee")]
-    Payee(payee::RemoveArguments),
+    /// Remove payee profile from payment plan(s).
+    Profile(profile::RemoveArguments),
 
     /// Remove payment parameters from payment plan(s).
-    #[structopt(name = "payment")]
     Payment(payment::RemoveArguments),
 
     /// Remove condition(s) from payment plan(s).
-    #[structopt(name = "condition")]
     Condition(condition::RemoveArguments),
 }
 
@@ -129,8 +125,8 @@ fn remove(subcommand: &RemoveSubcommands) -> Result<()> {
         RemoveSubcommands::Plan(args) => {
             plan::remove(&args)?;
         }
-        RemoveSubcommands::Payee(args) => {
-            payee::remove(&args)?;
+        RemoveSubcommands::Profile(args) => {
+            profile::remove(&args)?;
         }
         RemoveSubcommands::Payment(args) => {
             payment::remove(&args)?;
@@ -142,8 +138,27 @@ fn remove(subcommand: &RemoveSubcommands) -> Result<()> {
     Ok(())
 }
 
-fn show(_verbosity: u8) -> Result<()> {
-    let lock_handle = common::LockFileHandle::load(&None)?;
-    println!("{}", serde_json::to_string_pretty(&lock_handle.lock)?);
+#[derive(Debug, StructOpt, Clone)]
+pub struct UpdateArguments {
+    #[structopt(flatten)]
+    pub profile: profile::UpdateArguments,
+}
+
+fn update(args: &UpdateArguments) -> Result<()> {
+    profile::update(&args.profile)?;
+    Ok(())
+}
+
+#[derive(Debug, StructOpt, Clone)]
+pub struct ShowArguments {
+    /// Field path.
+    #[structopt(name = "field-path")]
+    pub path: Option<String>,
+}
+
+fn show(args: &ShowArguments) -> Result<()> {
+    let lock_handle = crate::handles::LockHandle::load(&None)?;
+    let value = lock_handle.get(&args.path)?;
+    println!("{}", serde_json::to_string_pretty(&value)?);
     Ok(())
 }
