@@ -43,7 +43,7 @@ pub struct AddCompulsoryArguments {
 }
 
 pub fn add_compulsory(args: &AddCompulsoryArguments) -> Result<()> {
-    let mut lock_handle = common::LockFileHandle::load(&args.lock_file_args.path)?;
+    let mut lock_handle = crate::handles::LockHandle::load(&args.lock_file_args.path)?;
     let id = openfare_lib::lock::plan::next_id(&lock_handle.lock.plans)?;
 
     let conditions = args.conditions.clone().try_into()?;
@@ -53,8 +53,7 @@ pub fn add_compulsory(args: &AddCompulsoryArguments) -> Result<()> {
         conditions,
         payments: openfare_lib::lock::plan::Payments {
             total: Some(
-                openfare_lib::lock::plan::price::Price::try_from(args.fee.as_str())
-                    .expect("parse fee price"),
+                openfare_lib::price::Price::try_from(args.fee.as_str()).expect("parse fee price"),
             ),
             shares: None,
         },
@@ -80,7 +79,7 @@ pub struct AddVoluntaryArguments {
 }
 
 pub fn add_voluntary(args: &AddVoluntaryArguments) -> Result<()> {
-    let mut lock_handle = common::LockFileHandle::load(&args.lock_file_args.path)?;
+    let mut lock_handle = crate::handles::LockHandle::load(&args.lock_file_args.path)?;
     let id = openfare_lib::lock::plan::next_id(&lock_handle.lock.plans)?;
     let plan = openfare_lib::lock::plan::Plan {
         r#type: openfare_lib::lock::plan::PlanType::Voluntary,
@@ -116,7 +115,7 @@ pub struct RemoveArguments {
 }
 
 pub fn remove(args: &RemoveArguments) -> Result<()> {
-    let mut lock_handle = common::LockFileHandle::load(&None)?;
+    let mut lock_handle = crate::handles::LockHandle::load(&None)?;
     let ids = if args.id.is_empty() {
         lock_handle
             .lock
@@ -144,7 +143,7 @@ pub fn remove(args: &RemoveArguments) -> Result<()> {
 
     if args.cleanup_payees {
         // Remove payees which are not present in plans.
-        let plan_payees_names: std::collections::BTreeSet<openfare_lib::lock::payee::Name> =
+        let plan_payees_names: std::collections::BTreeSet<openfare_lib::lock::payee::Label> =
             lock_handle
                 .lock
                 .plans
@@ -153,7 +152,7 @@ pub fn remove(args: &RemoveArguments) -> Result<()> {
                     if let Some(shares) = &plan.payments.shares {
                         Some(shares.iter()
                     .map(|(name, _share)| name.clone())
-                    .collect::<std::collections::BTreeSet<openfare_lib::lock::payee::Name>>())
+                    .collect::<std::collections::BTreeSet<openfare_lib::lock::payee::Label>>())
                     } else {
                         None
                     }
@@ -164,8 +163,8 @@ pub fn remove(args: &RemoveArguments) -> Result<()> {
             .lock
             .payees
             .iter()
-            .filter(|(payee_name, _)| plan_payees_names.contains(payee_name.as_str()))
-            .map(|(name, payee)| (name.clone(), payee.clone()))
+            .filter(|(payee_label, _)| plan_payees_names.contains(payee_label.as_str()))
+            .map(|(label, payee)| (label.clone(), payee.clone()))
             .collect();
     }
     Ok(())
