@@ -1,9 +1,6 @@
-use anyhow::Result;
-
-use crate::common;
-use crate::extension;
-
 use super::format;
+use crate::extensions;
+use anyhow::Result;
 
 /// Prints a price report for a specific package and its dependencies.
 pub fn price(
@@ -11,10 +8,10 @@ pub fn price(
     package_version: &Option<&str>,
     extension_names: &std::collections::BTreeSet<String>,
     extension_args: &Vec<String>,
-    config: &common::config::Config,
+    config: &crate::config::Config,
 ) -> Result<()> {
-    let extensions = extension::manage::get_enabled(&extension_names, &config)?;
-    let extensions_results = extension::package_dependencies_locks(
+    let extensions = extensions::manage::get_enabled(&extension_names, &config)?;
+    let extensions_results = extensions::package_dependencies_locks(
         &package_name,
         &package_version,
         &extensions,
@@ -25,8 +22,9 @@ pub fn price(
 
     for (extension, extension_result) in extensions.iter().zip(extensions_results.iter()) {
         log::debug!(
-            "Inspecting package OpenFare locks found by extension: {}",
-            extension.name()
+            "Inspecting package OpenFare locks found by extension: {name} ({version})",
+            name = extension.name(),
+            version = extension.version()
         );
 
         let extension_result = match extension_result {
@@ -45,10 +43,8 @@ pub fn price(
         if let Some(price_report) =
             crate::price::get_report(&extension_result.package_locks, &config)?
         {
-            println!(
-                "Registry: {name}",
-                name = extension_result.registry_host_name
-            );
+            println!("Registry: {}", extension_result.registry_host_name);
+            println!("Total: {}", price_report.price);
             format::print(&price_report, &format::Format::Table, true)?;
             println!("");
         }
