@@ -2,7 +2,7 @@ use anyhow::Result;
 
 pub fn get_report(
     package_locks: &openfare_lib::package::PackageLocks,
-    config: &crate::common::config::Config,
+    config: &crate::config::Config,
 ) -> Result<Option<PriceReport>> {
     log::info!("Generating price report for package and it's dependencies.");
 
@@ -38,7 +38,7 @@ pub fn get_report(
 
     let price_report = PriceReport {
         package_reports: package_reports,
-        price: openfare_lib::lock::plan::price::Price {
+        price: openfare_lib::price::Price {
             quantity: rust_decimal::Decimal::from(total_price),
             currency: config.core.preferred_currency.clone(),
         },
@@ -49,14 +49,14 @@ pub fn get_report(
 #[derive(Debug, Clone, Eq, Ord, PartialEq, PartialOrd)]
 pub struct PriceReport {
     pub package_reports: Vec<PackagePriceReport>,
-    pub price: openfare_lib::lock::plan::price::Price,
+    pub price: openfare_lib::price::Price,
 }
 
 #[derive(Debug, Clone, Eq, Ord, PartialEq, PartialOrd)]
 pub struct PackagePriceReport {
     pub package: openfare_lib::package::Package,
     pub plan_id: Option<openfare_lib::lock::plan::Id>,
-    pub price_quantity: Option<openfare_lib::lock::plan::price::Quantity>,
+    pub price_quantity: Option<openfare_lib::price::Quantity>,
     pub notes: Vec<String>,
 }
 
@@ -64,7 +64,7 @@ pub struct PackagePriceReport {
 fn get_package_price_report(
     package: &openfare_lib::package::Package,
     package_lock: &Option<openfare_lib::lock::Lock>,
-    config: &crate::common::config::Config,
+    config: &crate::config::Config,
 ) -> Result<PackagePriceReport> {
     let package_lock = match package_lock {
         Some(c) => c,
@@ -78,8 +78,10 @@ fn get_package_price_report(
         }
     };
 
-    let applicable_plans =
-        openfare_lib::lock::plan::filter_applicable(&package_lock.plans, &config.profile)?;
+    let applicable_plans = openfare_lib::lock::plan::filter_applicable(
+        &package_lock.plans,
+        &config.profile.parameters,
+    )?;
 
     Ok(
         if let Some((plan_id, plan)) = select_plan(&applicable_plans) {
